@@ -1,6 +1,7 @@
+"""Module that allow the authentification by register the personnal token"""
+
 import getpass
 import json
-import os
 from pathlib import Path
 
 
@@ -12,7 +13,7 @@ def login_args_configuration(sub_parser):
     login_parser.set_defaults(func=login)
 
 
-def login():
+def login(_):
     """
     Login function that create a subdirectory and store the token
     """
@@ -24,7 +25,8 @@ def login():
     with open(path, "w+") as config_file:
         try:
             data = json.load(config_file)
-        except:
+        finally:
             pass
         data["pat"] = getpass.getpass("PAT:")
+        data["size_limit"] = 40
         json.dump(data, config_file)
